@@ -60,7 +60,7 @@ void show_error(gchar * msg)
 	GtkWidget *dialog;
 
 	dialog = gtk_message_dialog_new(GTK_WINDOW(girl_app),
-					GTK_DIALOG_MODAL, 				
+					GTK_DIALOG_MODAL,
 					GTK_MESSAGE_ERROR,
 					GTK_BUTTONS_CLOSE, msg, NULL);
 	gtk_dialog_run(GTK_DIALOG(dialog));
@@ -380,7 +380,6 @@ void girl_helper_run(gchar *url, gchar *name, GirlStreamType type, GirlHelperTyp
 						 NULL);
 		}
 #endif
-		
 	}
 	
 	if (helper == GIRL_STREAM_RECORD) {
@@ -403,8 +402,7 @@ void girl_helper_run(gchar *url, gchar *name, GirlStreamType type, GirlHelperTyp
 			GIRL_DEBUG_MSG("Launching %s\n", command);
 			g_subprocess_wait_async (girl->record_subprocess,
 						 record_cancellable,
-						 (GAsyncReadyCallback)cb_subprocess_record,						 
-						 NULL);
+						 (GAsyncReadyCallback)cb_subprocess_record, NULL);
 		}
 
 #if 0
